@@ -3,8 +3,7 @@
 /*               This file is part of the program and library                */
 /*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
 /*                                                                           */
-/* Copyright (C) 2020-2023 Konrad-Zuse-Zentrum                               */
-/*                     fuer Informationstechnik Berlin                       */
+/* Copyright (C) 2020-2024 Zuse Institute Berlin (ZIB)                       */
 /*                                                                           */
 /* This program is free software: you can redistribute it and/or modify      */
 /* it under the terms of the GNU Lesser General Public License as published  */
@@ -26,17 +25,19 @@
 
 #define PAPILO_HAVE_FLOAT128
 #define PAPILO_HAVE_GMP
+#define PAPILO_COMMAND_LINE_AVAILABLE
+#define PAPILO_SERIALIZATION_AVAILABLE
 /* #undef PAPILO_HAVE_LUSOL */
 #define PAPILO_USE_STANDARD_HASHMAP
 #define PAPILO_USE_BOOST_IOSTREAMS_WITH_ZLIB
 #define PAPILO_USE_BOOST_IOSTREAMS_WITH_BZIP2
-/* #undef PAPILO_GITHASH_AVAILABLE */
+#define PAPILO_GITHASH_AVAILABLE
 #define BOOST_FOUND
 #define PAPILO_TBB
 
 #define PAPILO_VERSION_MAJOR 2
-#define PAPILO_VERSION_MINOR 1
-#define PAPILO_VERSION_PATCH 3
+#define PAPILO_VERSION_MINOR 2
+#define PAPILO_VERSION_PATCH 1
 #define PAPILO_VERSION_TWEAK 0
 
 #ifdef PAPILO_HAVE_GMP
@@ -44,7 +45,7 @@
 #endif
 
 #ifdef PAPILO_GITHASH_AVAILABLE
-   #define PAPILO_GITHASH ""
+   #define PAPILO_GITHASH "3f1f0d53"
 #endif
 
 #endif
