@@ -3,8 +3,7 @@
 /*               This file is part of the program and library                */
 /*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
 /*                                                                           */
-/* Copyright (C) 2020-2023 Konrad-Zuse-Zentrum                               */
-/*                     fuer Informationstechnik Berlin                       */
+/* Copyright (C) 2020-2024 Zuse Institute Berlin (ZIB)                       */
 /*                                                                           */
 /* This program is free software: you can redistribute it and/or modify      */
 /* it under the terms of the GNU Lesser General Public License as published  */
@@ -63,8 +62,8 @@ class PrimalDualSolValidation
    {
       bool failure = false;
 
-      const Vec<REAL> ub = problem.getUpperBounds();
-      const Vec<REAL> lb = problem.getLowerBounds();
+      const Vec<REAL>& ub = problem.getUpperBounds();
+      const Vec<REAL>& lb = problem.getLowerBounds();
 
       for( int col = 0; col < problem.getNCols(); col++ )
       {
@@ -92,8 +91,8 @@ class PrimalDualSolValidation
    checkPrimalConstraintAndUpdateSlack( Solution<REAL>& solution,
                                         const Problem<REAL>& problem ) const
    {
-      const Vec<REAL> rhs = problem.getConstraintMatrix().getRightHandSides();
-      const Vec<REAL> lhs = problem.getConstraintMatrix().getLeftHandSides();
+      const Vec<REAL>& rhs = problem.getConstraintMatrix().getRightHandSides();
+      const Vec<REAL>& lhs = problem.getConstraintMatrix().getLeftHandSides();
 
       if(solution.type == SolutionType::kPrimalDual)
       {
